==> model1-1.0.3.8.tar.gz: model1-1.0.3.8/model1/goods/main.py <==
from skyext import EXT_CONTEXT
from skyext.utils.db_utils import query2dict
from model1.goods.model import Goods


class GoodsManager(object):

    def get(self, **params):
        if params:
            for i in params:
                print("find params===>key={0},value={1}".format(i, params[i]))
        if not params and params.keys().__contains__('id'):
            raise Exception("find user, params[id] is not existed")

        with EXT_CONTEXT["db"].session_maker() as session:
            role = session.query(Goods).filter(Goods.id == params.get("id")).one()
            if role:
                print('type:', type(role))
                print('name:', role.name)
                return query2dict(role)
            else:
                return None


    def post(self, **params):
        if params:
            for i in params:
                print("find params===>key={0},value={1}".format(i, params[i]))

        if not params and params.keys().__contains__('id'):
            raise Exception("find user, params[id] is not existed")

        with EXT_CONTEXT["db"].session_maker() as session:
            list = session.query(Goods).filter(Goods.id == params.get("id")).all()
            if list:
                print('type:', type(list))
                return query2dict(list)
            else:
                return None

    def delete(self, **params):
        if params:
            for i in params:
                print("find params===>key={0},value={1}".format(i, params[i]))

        if not params and params.keys().__contains__('id'):
            raise Exception("find user, params[id] is not existed")

        with EXT_CONTEXT["db"].session_maker() as session:
            _model = session.query(Goods).filter(Goods.id == params.get("id")).first()
            if _model:
                session.delete(_model)
                return query2dict(_model)
            else:
                return None

    def put(self, **params):
        if params:
            for i in params:
                print("find params===>key={0},value={1}".format(i, params[i]))

        if not params and params.keys().__contains__('id'):
            raise Exception("find user, params[id] is not existed")

        if not params and params.keys().__contains__('name'):
            raise Exception("find user, params[id] is not existed")

        with EXT_CONTEXT["db"].session_maker() as session:
            _model = session.query(Goods).filter(Goods.id == params.get("id")).first()
            if _model:
                _model.name = params.get("name")
                return query2dict(_model)
            else:
                return None

==> model1-1.0.4.1.tar.gz: model1-1.0.4.1/model1/goods/main.py <==
from skyext import EXT_CONTEXT
from skyext.intercepter.db_session_intercepter import db_session_decorator
from skyext.utils.db_utils import query2dict
from model1.goods.model import Goods


class GoodsManager(object):

    @db_session_decorator
    def get_test(self, **params):
        if params:
            for i in params:
                print("find params===>key={0},value={1}".format(i, params[i]))
        if params and not params.keys().__contains__('id'):
            raise Exception("find goods, params[id] is not existed")

        session = params.get("db_session")
        role = session.query(Goods).filter(Goods.id == params.get("id")).one()
        if role:
            print('type:', type(role))
            print('name:', role.name)
            return query2dict(role)
        else:
            return None

    def get(self, **params):
        if params:
            for i in params:
                print("find params===>key={0},value={1}".format(i, params[i]))
        if not params and params.keys().__contains__('id'):
            raise Exception("find user, params[id] is not existed")

        with EXT_CONTEXT["db"].session_maker() as session:
            role = session.query(Goods).filter(Goods.id == params.get("id")).one()
            if role:
                print('type:', type(role))
                print('name:', role.name)
                return query2dict(role)
            else:
                return None


    def post(self, **params):
        if params:
            for i in params:
                print("find params===>key={0},value={1}".format(i, params[i]))

        if not params and params.keys().__contains__('id'):
            raise Exception("find user, params[id] is not existed")

        with EXT_CONTEXT["db"].session_maker() as session:
            list = session.query(Goods).filter(Goods.id == params.get("id")).all()
            if list:
                print('type:', type(list))
                return query2dict(list)
            else:
                return None

    def delete(self, **params):
        if params:
            for i in params:
                print("find params===>key={0},value={1}".format(i, params[i]))

        if not params and params.keys().__contains__('id'):
            raise Exception("find user, params[id] is not existed")

        with EXT_CONTEXT["db"].session_maker() as session:
            _model = session.query(Goods).filter(Goods.id == params.get("id")).first()
            if _model:
                session.delete(_model)
                return query2dict(_model)
            else:
                return None

    def put(self, **params):
        if params:
            for i in params:
                print("find params===>key={0},value={1}".format(i, params[i]))

        if not params and params.keys().__contains__('id'):
            raise Exception("find user, params[id] is not existed")

        if not params and params.keys().__contains__('name'):
            raise Exception("find user, params[id] is not existed")

        with EXT_CONTEXT["db"].session_maker() as session:
            _model = session.query(Goods).filter(Goods.id == params.get("id")).first()
            if _model:
                _model.name = params.get("name")
                return query2dict(_model)
            else:
                return None
